@@ -1,8 +1,9 @@
 from mongoengine import Document
-import os
+import os, sys, mongoengine.connection
+from mongoengine.connection import DEFAULT_CONNECTION_NAME
 
 from objects import Database
-from overloads import new_get_collection, new_get_db
+from overloads import new_get_collection, new_get_db, new_get_connection
 import overloads, json
 
 _project_root = None
@@ -13,6 +14,12 @@ def connect(db_name):
 
     _project_root = os.getcwd()
     overloads._db_file_name = db_name
+    
+    sys.modules['mongoengine.connection'].DEFAULT_CONNECTION_NAME = db_name
+    sys.modules['mongoengine.connection'].get_connection = new_get_connection
+    
+    mongoengine.connection._connection_settings[DEFAULT_CONNECTION_NAME] = dict(name=db_name, username=None, password=None)
+
     if '.json' not in db_name:
         db_name = db_name + '.json'
 
@@ -32,4 +39,6 @@ def connect(db_name):
     Document._get_db = new_get_db
 
     # Override mongoengine _get_collection function
-    Document._get_collection = new_get_collection
\ No newline at end of file
+    Document._get_collection = new_get_collection
+    
+    return new_get_connection()
